@@ -1,11 +1,12 @@
 package org.gcube.applicationsupportlayer.social;
 
+import java.util.Date;
 import java.util.List;
 
 import org.gcube.portal.databook.shared.ApplicationProfile;
 import org.gcube.portal.databook.shared.RunningJob;
-import org.gcube.portlets.user.homelibrary.home.workspace.WorkspaceFolder;
-import org.gcube.portlets.user.homelibrary.home.workspace.WorkspaceItem;
+import org.gcube.common.homelibrary.home.workspace.WorkspaceFolder;
+import org.gcube.common.homelibrary.home.workspace.WorkspaceItem;
 /**
  * 
  * @author Massimiliano Assante, ISTI-CNR
@@ -71,7 +72,16 @@ public interface NotificationsManager {
 	 * @param sharedFolder the shared folder {@link WorkspaceFolder} 
 	 * @return true if the notification is correctly delivered, false otherwise
 	 */
-	boolean notifyRemovedItem(String userIdToNotify, WorkspaceItem item, WorkspaceFolder sharedFolder) throws Exception;
+	boolean notifyMovedItem(String userIdToNotify, WorkspaceItem item, WorkspaceFolder sharedFolder) throws Exception;
+	/**
+	 * use to notify a user he got a workspace item deleted from one of his workspace shared folder
+	 * @param userIdToNotify the user you want to notify
+	 * @param removedItem the removed {@link WorkspaceItem}  
+	 * @param sharedFolder the shared folder {@link WorkspaceFolder} 
+	 * @return true if the notification is correctly delivered, false otherwise
+	 */
+	boolean notifyRemovedItem(String userIdToNotify, String item, WorkspaceFolder sharedFolder) throws Exception;
+	
 	/**
 	 * use to notify a user he got a workspace item updated from one of his workspace shared folder
 	 * @param userIdToNotify the user you want to notify
@@ -96,6 +106,45 @@ public interface NotificationsManager {
 	 * @return true if the notification is correctly delivered, false otherwise
 	 */
 	boolean notifyMessageReceived(String userIdToNotify, String subject);
+	/**
+	 * 
+	 * @param userIdToNotify the user you want to notify
+	 * @param eventTitle the title of the event
+	 * @param eventType the type of the event
+	 * @param startDate staring date
+	 * @param endingDate ending date
+	 * @return true if the notification is correctly delivered, false otherwise
+	 */
+	boolean notifyNewCalendarEvent(String userIdToNotify, String eventTitle, String eventType, Date startDate, Date endingDate);
+	/**
+	 * 
+	 * @param userIdToNotify the user you want to notify
+	 * @param eventTitle the title of the event
+	 * @param eventType the type of the event
+	 * @param startDate staring date
+	 * @param endingDate ending date
+	 * @return true if the notification is correctly delivered, false otherwise
+	 */
+	boolean notifyEditedCalendarEvent(String userIdToNotify, String eventTitle, String eventType, Date startDate, Date endingDate);
+	/**
+	 * 
+	 * @param userIdToNotify the user you want to notify
+	 * @param eventTitle the title of the event
+	 * @param eventType the type of the event
+	 * @param startDate staring date
+	 * @param endingDate ending date
+	 * @return true if the notification is correctly delivered, false otherwise
+	 */
+	boolean notifyDeletedCalendarEvent(String userIdToNotify, String eventTitle, String eventType, Date startDate, Date endingDate);
+	/**
+	 * use to notify a user that someone created this post
+	 * 
+	 * @param userIdToNotify the user you want to notify
+	 * @param feedid the liked feedid 
+	 * @param feedText the liked feed text or a portion of it
+	 * @return true if the notification is correctly delivered, false otherwise
+	 */
+	boolean notifyPost(String userIdToNotify, String feedid, String feedText);
 	/**
 	 * use to notify a user that someone commented on his post
 	 * 
@@ -111,9 +160,28 @@ public interface NotificationsManager {
 	 * @param userIdToNotify the user you want to notify
 	 * @param feedid the liked feedid 
 	 * @param feedText the liked feed text or a portion of it
+	 * @param feedOwnerFullName the full name of the user who created this post
 	 * @return true if the notification is correctly delivered, false otherwise
 	 */
-	boolean notifyCommentReply(String userIdToNotify, String feedid, String feedText);
+	boolean notifyCommentReply(String userIdToNotify, String feedid, String feedText, String feedOwnerFullName);
+	/**
+	 * use to notify a user that someone commented on one of his favorite posts 
+	 * 
+	 * @param userIdToNotify the user you want to notify
+	 * @param feedid the liked feedid 
+	 * @param commentText the commentText
+	 * @return true if the notification is correctly delivered, false otherwise
+	 */
+	boolean notifyCommentOnFavorite(String userIdToNotify, String feedid, String commentText);
+	/**
+	 * use to notify a user that he was mentioned (tagged) on a post
+	 * 
+	 * @param userIdToNotify the user you want to notify
+	 * @param feedid the liked feedid 
+	 * @param feedText the liked feed text or a portion of it
+	 * @return true if the notification is correctly delivered, false otherwise
+	 */
+	boolean notifyUserTag(String userIdToNotify, String feedid, String commentText);
 	/**
 	 * use to notify a user he got one of his post liked
 	 *  
